@@ -126,6 +126,12 @@ from .helpers.cache import (
     exponential_backoff_with_jitter,
 )
 
+# Export JWT verification utilities
+from .helpers.core import (
+    verify_jwt_locally,
+    is_jwt_valid,
+)
+
 # Export error classes
 from .errors import (
     DominusError,
@@ -140,7 +146,7 @@ from .errors import (
     TimeoutError as DominusTimeoutError,
 )
 
-__version__ = "2.7.1"
+__version__ = "2.8.0"
 __all__ = [
     # Main SDK instance
     "dominus",
@@ -186,6 +192,9 @@ __all__ = [
     "DominusCache",
     "orchestrator_circuit_breaker",
     "exponential_backoff_with_jitter",
+    # JWT verification utilities
+    "verify_jwt_locally",
+    "is_jwt_valid",
     # Error classes
     "DominusError",
     "AuthenticationError",
